@@ -1,6 +1,6 @@
 from project.business_service.remove_operations import remove_operations
 from project.core.settings import get_cached_settings
-from project.core.util import setup_logging
+from project.core.setup_logging import setup_logging
 
 
 def __command():
